@@ -32,7 +32,7 @@ struct _DzlGraphColumn
 {
   GObject  parent_instance;
   gchar   *name;
-  DzlRing  *values;
+  DzlRing *values;
   GType    value_type;
 };
 
@@ -49,7 +49,7 @@ static GParamSpec *properties [LAST_PROP];
 
 DzlGraphColumn *
 dzl_graph_view_column_new (const gchar *name,
-               GType        value_type)
+                           GType        value_type)
 {
   return g_object_new (DZL_TYPE_GRAPH_COLUMN,
                        "name", name,
@@ -66,8 +66,8 @@ dzl_graph_view_column_get_name (DzlGraphColumn *self)
 }
 
 void
-dzl_graph_view_column_set_name (DzlGraphColumn    *self,
-                    const gchar *name)
+dzl_graph_view_column_set_name (DzlGraphColumn *self,
+                                const gchar    *name)
 {
   g_return_if_fail (DZL_IS_GRAPH_COLUMN (self));
 
@@ -81,7 +81,7 @@ dzl_graph_view_column_set_name (DzlGraphColumn    *self,
 
 static void
 dzl_graph_view_column_copy_value (gpointer data,
-                      gpointer user_data)
+                                  gpointer user_data)
 {
   const GValue *src_value = data;
   DzlRing *ring = user_data;
@@ -98,7 +98,7 @@ dzl_graph_view_column_copy_value (gpointer data,
 
 void
 _dzl_graph_view_column_set_n_rows (DzlGraphColumn *self,
-                       guint     n_rows)
+                                   guint           n_rows)
 {
   DzlRing *ring;
 
@@ -107,7 +107,7 @@ _dzl_graph_view_column_set_n_rows (DzlGraphColumn *self,
 
   ring = dzl_ring_sized_new (sizeof (GValue), n_rows, NULL);
   dzl_ring_foreach (self->values, dzl_graph_view_column_copy_value, ring);
-  dzl_clear_pointer (&self->values, dzl_ring_unref);
+  g_clear_pointer (&self->values, dzl_ring_unref);
   self->values = ring;
 }
 
@@ -127,8 +127,8 @@ _dzl_graph_view_column_push (DzlGraphColumn *self)
 
 void
 _dzl_graph_view_column_get_value (DzlGraphColumn *self,
-                      guint     index,
-                      GValue   *value)
+                                  guint           index,
+                                  GValue         *value)
 {
   const GValue *src_value;
 
@@ -143,10 +143,31 @@ _dzl_graph_view_column_get_value (DzlGraphColumn *self,
     g_value_copy (src_value, value);
 }
 
+void
+_dzl_graph_view_column_set_value (DzlGraphColumn *self,
+                                  guint           index,
+                                  const GValue   *value)
+{
+  GValue *dst_value;
+
+  g_return_if_fail (DZL_IS_GRAPH_COLUMN (self));
+  g_return_if_fail (value != NULL);
+  g_return_if_fail (index < self->values->len);
+  g_return_if_fail (G_VALUE_TYPE (value) == self->value_type);
+
+  dst_value = &((GValue *)(gpointer)self->values->data)[index];
+
+  if (G_VALUE_TYPE (dst_value) != G_TYPE_INVALID)
+    g_value_unset (dst_value);
+
+  g_value_init (dst_value, G_VALUE_TYPE (value));
+  g_value_copy (value, dst_value);
+}
+
 void
 _dzl_graph_view_column_collect (DzlGraphColumn *self,
-                    guint     index,
-                    va_list   args)
+                                guint           index,
+                                va_list         args)
 {
   GValue *value;
   gchar *errmsg = NULL;
@@ -167,8 +188,8 @@ _dzl_graph_view_column_collect (DzlGraphColumn *self,
 
 void
 _dzl_graph_view_column_set (DzlGraphColumn *self,
-                guint     index,
-                ...)
+                            guint           index,
+                            ...)
 {
   va_list args;
 
@@ -182,8 +203,8 @@ _dzl_graph_view_column_set (DzlGraphColumn *self,
 
 void
 _dzl_graph_view_column_get (DzlGraphColumn *self,
-                guint     index,
-                ...)
+                            guint           index,
+                            ...)
 {
   va_list args;
 
@@ -197,8 +218,8 @@ _dzl_graph_view_column_get (DzlGraphColumn *self,
 
 void
 _dzl_graph_view_column_lcopy (DzlGraphColumn *self,
-                  guint     index,
-                  va_list   args)
+                              guint           index,
+                              va_list         args)
 {
   const GValue *value;
   gchar *errmsg = NULL;
@@ -225,17 +246,17 @@ dzl_graph_view_column_finalize (GObject *object)
 {
   DzlGraphColumn *self = (DzlGraphColumn *)object;
 
-  dzl_clear_pointer (&self->name, g_free);
-  dzl_clear_pointer (&self->values, dzl_ring_unref);
+  g_clear_pointer (&self->name, g_free);
+  g_clear_pointer (&self->values, dzl_ring_unref);
 
   G_OBJECT_CLASS (dzl_graph_view_column_parent_class)->finalize (object);
 }
 
 static void
 dzl_graph_view_column_get_property (GObject    *object,
-                        guint       prop_id,
-                        GValue     *value,
-                        GParamSpec *pspec)
+                                    guint       prop_id,
+                                    GValue     *value,
+                                    GParamSpec *pspec)
 {
   DzlGraphColumn *self = DZL_GRAPH_COLUMN (object);
 
@@ -256,9 +277,9 @@ dzl_graph_view_column_get_property (GObject    *object,
 
 static void
 dzl_graph_view_column_set_property (GObject      *object,
-                        guint         prop_id,
-                        const GValue *value,
-                        GParamSpec   *pspec)
+                                    guint         prop_id,
+                                    const GValue *value,
+                                    GParamSpec   *pspec)
 {
   DzlGraphColumn *self = DZL_GRAPH_COLUMN (object);
 
